/* tslint:disable:max-line-length */
import { Tixin } from '@tdm/tixin';
import { targetStore } from '@tdm/core/tdm';
import { store, plugins } from '@tdm/data';
import { HttpAdapter } from '../core/index';
import { HttpActiveRecord } from './http-active-record';
/**
 * @template Model, TypeofModel, TMIXIN, CMIXIN
 * @param {?=} model
 * @param {...?} mixins
 * @return {?}
 */
export function ARMixin(model) {
    var mixins = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        mixins[_i - 1] = arguments[_i];
    }
    plugins.assertPlugin('ActiveRecord'); // make sure plugin attached
    if (!model) {
        model = ((function () {
            function class_1() {
            }
            return class_1;
        }()));
    }
    // a model might not be a target at this point (i.e. it has no metadata)
    targetStore.registerTarget(model);
    /**
     * Marking the mixin HttpActiveRecord for model.
     * Since model is an extending class, it's type will be traversed and looked up for mixins
     * so the deriving class (base) will get all the actions from the HttpActiveRecord
     *
     */
    store.markMixins.apply(store, [model, HttpAdapter, HttpActiveRecord].concat(mixins));
    // we can't send ...mixin to Tixin since the type limits the ..mixins amount
    var /** @type {?} */ result = ((Tixin)).apply(void 0, [model, HttpActiveRecord].concat(mixins));
    var /** @type {?} */ tMeta = targetStore.getTargetMeta(result);
    if (tMeta.hasModel) {
        tMeta.model().build(true);
    }
    return (result);
}
/* tslint:disable:max-line-length */
//# sourceMappingURL=ar-mixin.js.map