import { pathToRegexp, compile } from './path-to-regexp';
var /** @type {?} */ REGEXP_CACHE = new Map();
var /** @type {?} */ COMPILED_CACHE = new Map();
/**
 * @param {?} pattern
 * @return {?}
 */
export function getRegexp(pattern) {
    if (!REGEXP_CACHE.has(pattern)) {
        var /** @type {?} */ keys = [];
        var /** @type {?} */ regexp = pathToRegexp(pattern, keys, { end: false });
        REGEXP_CACHE.set(pattern, { keys: keys, regexp: regexp });
    }
    return REGEXP_CACHE.get(pattern);
}
/**
 * @param {?} pattern
 * @return {?}
 */
export function getCompiled(pattern) {
    if (!COMPILED_CACHE.has(pattern)) {
        COMPILED_CACHE.set(pattern, /** @type {?} */ (compile(pattern)));
    }
    return COMPILED_CACHE.get(pattern);
}
/**
 * @param {?} pattern
 * @param {?} pathname
 * @return {?}
 */
export function matchPattern(pattern, pathname) {
    if (pattern.charAt(0) !== '/') {
        pattern = "/" + pattern;
    }
    var /** @type {?} */ compiled = getRegexp(pattern);
    var /** @type {?} */ match = compiled.regexp.exec(pathname);
    if (!match) {
        return {
            remainingPathname: null,
            paramNames: [],
            paramValues: []
        };
    }
    return {
        remainingPathname: pathname.substr(match[0].length),
        paramNames: compiled.keys.map(function (key) { return key.name; }),
        paramValues: match.slice(1).map(function (value) { return value && decodeURIComponent(value); })
    };
}
/**
 * @param {?} pattern
 * @return {?}
 */
export function getParamNames(pattern) {
    return getRegexp(pattern).keys.map(function (key) { return key.name; });
}
/**
 * @param {?} paramNames
 * @param {?} paramValues
 * @return {?}
 */
export function makeParams(paramNames, paramValues) {
    var /** @type {?} */ params = {};
    var /** @type {?} */ lastIndex = 0;
    if (Array.isArray(paramValues)) {
        paramNames.forEach(function (paramName, index) {
            if (typeof paramName === 'number') {
                paramName = lastIndex++;
            }
            params[paramName] = paramValues[index];
        });
    }
    return params;
}
/**
 * @param {?} pattern
 * @param {?} pathname
 * @return {?}
 */
export function getParams(pattern, pathname) {
    var _a = matchPattern(pattern, pathname), remainingPathname = _a.remainingPathname, paramNames = _a.paramNames, paramValues = _a.paramValues;
    if (remainingPathname === null) {
        return null;
    }
    return makeParams(paramNames, paramValues);
}
/**
 * @param {?} pattern
 * @param {?=} params
 * @return {?}
 */
export function formatPattern(pattern, params) {
    if (params === void 0) { params = {}; }
    return getCompiled(pattern)(params);
}
//# sourceMappingURL=match-pattern.js.map