import { PathRegExp } from 'path-to-regexp';
/**
 * Parse a string for the raw tokens.
 *
 * @param  {string}  str
 * @param  {Object=} options
 * @return {!Array}
 */
export declare function parse(str: any, options: any): any[];
/**
 * Compile a string to a template function for the path.
 *
 * @param  {string}             str
 * @param  {Object=}            options
 * @return {!function(Object=, Object=)}
 */
export declare function compile(str: any, options?: any): (obj: any, opts: any) => string;
/**
 * Expose a method for transforming tokens into the path function.
 */
export declare function tokensToFunction(tokens: any): (obj: any, opts: any) => string;
/**
 * Expose a function for taking tokens and returning a RegExp.
 *
 * @param  {!Array}          tokens
 * @param  {(Array|Object)=} keys
 * @param  {Object=}         options
 * @return {!RegExp}
 */
export declare function tokensToRegExp(tokens: any, keys: any, options: any): any;
/**
 * Normalize the given path string, returning a regular expression.
 *
 * An empty array can be passed in for the keys, which will hold the
 * placeholder key descriptions. For example, using `/user/:id`, `keys` will
 * contain `[{ name: 'id', delimiter: '/', optional: false, repeat: false }]`.
 *
 * @param  {(string|RegExp|Array)} path
 * @param  {(Array|Object)=}       keys
 * @param  {Object=}               options
 * @return {!RegExp}
 */
export declare function pathToRegexp(path: any, keys?: any, options?: any): PathRegExp;
